@@ -767,14 +767,10 @@ our $dispatch_map = {
     "INTERVAL REPORT _TSRANGE" => \&interval_tsrange,
     "EMPLOYEE_SPEC INTERVAL REPORT _TSRANGE" => \&interval_tsrange,
 
-    "INTERVAL FILLUP _DATELIST" => \&interval_datelist,
-    "EMPLOYEE_SPEC INTERVAL FILLUP _DATELIST" => \&interval_datelist,
-    "INTERVAL FILLUP DRY_RUN _DATELIST" => \&interval_datelist,
-    "EMPLOYEE_SPEC INTERVAL FILLUP DRY_RUN _DATELIST" => \&interval_datelist,
-    "INTERVAL FILLUP _MONTH _DATELIST" => \&interval_datelist,
-    "EMPLOYEE_SPEC INTERVAL FILLUP _MONTH _DATELIST" => \&interval_datelist,
-    "INTERVAL FILLUP DRY_RUN _MONTH _DATELIST" => \&interval_datelist,
-    "EMPLOYEE_SPEC INTERVAL FILLUP DRY_RUN _MONTH _DATELIST" => \&interval_datelist,
+    "INTERVAL FILLUP DATELIST _TERM" => \&interval_datelist,
+    "EMPLOYEE_SPEC INTERVAL FILLUP DATELIST _TERM" => \&interval_datelist,
+    "INTERVAL FILLUP DATELIST DRY_RUN _TERM" => \&interval_datelist,
+    "EMPLOYEE_SPEC INTERVAL FILLUP DATELIST DRY_RUN _TERM" => \&interval_datelist,
 
     # add/insert new intervals
     "INTERVAL _TIME _TIME1 _TERM" => \&interval_new_time_time1,
